@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for imagebuilder service client
 
@@ -7,16 +8,14 @@ Usage::
     import boto3
     from mypy_boto3_imagebuilder import ImagebuilderClient
 
-    session = boto3.Session()
-
     client: ImagebuilderClient = boto3.client("imagebuilder")
-    session_client: ImagebuilderClient = session.client("imagebuilder")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type
+from typing import Any, Dict, List, Type
+
 from botocore.exceptions import ClientError as Boto3ClientError
+
 from mypy_boto3_imagebuilder.type_defs import (
     CancelImageCreationResponseTypeDef,
     ComponentConfigurationTypeDef,
